@@ -3,7 +3,7 @@ import logging
 
 class Default(object):
     WORKSPACE_URL = 'https://sdk.hackle.io/api/v2/workspaces'
-    EVENT_URL = 'https://sdk.hackle.io/api/v2/events'
+    EVENT_URL = 'https://event.hackle.io/api/v2/events'
     SDK_KEY_HEADER = 'X-HACKLE-SDK-KEY'
     SDK_NAME_HEADER = 'X-HACKLE-SDK-NAME'
     SDK_VERSION_HEADER = 'X-HACKLE-SDK-VERSION'
