@@ -21,17 +21,17 @@ class Serializer(object):
 
 
 class EventDispatcher(object):
-    event_url = enums.Default.EVENT_URL
+    def __init__(self):
+        self.event_url = enums.Default.EVENT_URL
 
-    @classmethod
-    def dispatch_event(cls, sdk_key, event):
+    def dispatch_event(self, sdk_key, event):
         request_headers = {enums.Default.SDK_KEY_HEADER: sdk_key,
                            enums.Default.SDK_NAME_HEADER: 'python-sdk',
                            enums.Default.SDK_VERSION_HEADER: version.__version__,
                            enums.Default.CONTENT_TYPE_HEADER: enums.Default.SDK_CONTENT_TYPE}
 
         try:
-            requests.post(cls.event_url, data=json.dumps(event, cls=EventEncoder), headers=request_headers,
+            requests.post(self.event_url, data=json.dumps(event, cls=EventEncoder), headers=request_headers,
                           timeout=enums.Default.REQUEST_TIMEOUT).raise_for_status()
 
         except request_exception.RequestException as error:
