@@ -1,7 +1,7 @@
 import logging
 import warnings
 
-from .commons import enums
+from hackle.commons import enums
 
 _DEFAULT_LOG_FORMAT = '%(levelname)-8s %(threadName)s %(asctime)s %(filename)s:%(lineno)s:%(message)s'
 
